aboutsummaryrefslogtreecommitdiff
path: root/libbpkg/manifest.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbpkg/manifest.hxx')
-rw-r--r--libbpkg/manifest.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/libbpkg/manifest.hxx b/libbpkg/manifest.hxx
index b9e7f92..a017772 100644
--- a/libbpkg/manifest.hxx
+++ b/libbpkg/manifest.hxx
@@ -613,7 +613,7 @@ namespace bpkg
// Traits class for the repository URL object.
//
- enum class repository_protocol {file, http, https, git};
+ enum class repository_protocol {file, http, https, git, ssh};
struct LIBBPKG_EXPORT repository_url_traits
{
@@ -704,7 +704,7 @@ namespace bpkg
//
// 2. If path has the .git extension then git.
//
// 3. If scheme is http(s) then pkg.
//
// 4. If local, check if directory contains the .git/ subdirectory then
// git, otherwise pkg.
@@ -704,7 +704,7 @@ namespace bpkg
// 2. If path has the .git extension then git.
//
- // 3. If scheme is http(s) then pkg.
+ // 3. If scheme is http(s) or ssh then pkg.
//
// 4. If local, check if directory contains the .git/ subdirectory then